﻿using System;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Threading.Tasks;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace DataBinding
{
    public sealed partial class MainPage : Page, INotifyPropertyChanged
    {
        private int msDelay;        

        public int MsDelay
        {
            get
            {
                return msDelay;
            }
            private set
            {
                msDelay = value;
                OnPropertyChanged();
            }
        }

        public event PropertyChangedEventHandler PropertyChanged = delegate { };

        public MainPage()
        {            
            InitializeComponent();                    
        }

        public void OnPropertyChanged([CallerMemberName] string propertyName = "")
        {
            PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        private async void Button_Click(object sender, RoutedEventArgs e)
        {
            Button button = sender as Button;

            if (button != null)
            {
                button.IsEnabled = false;

                await BackgroundAction();

                button.IsEnabled = true;
            }
        }

        private Task BackgroundAction()
        {
            const int msDelay = 50;
            const int iterationsCount = 100;

            return Task.Run(async () =>
            {
                for (int i = 1; i <= iterationsCount; i++)
                {                    
                    await Dispatcher.RunIdleAsync((a) => { MsDelay = i; });

                    Task.Delay(msDelay).Wait();
                }
            });
        }

        private string Sum(double val1, double val2)
        {
            return "Sum: " + (val1 + val2).ToString();
        }
    }   
}
