﻿using ArgumentValidation;
using OxyPlot;
using OxyPlot.Series;
using System;

namespace FrequencyDistribution
{
    public static class PlotHelper
    {
        public static short[] GenerateSineWave(int length, double frequency)
        {
            Check.IsLargerThanZero(length);

            double degToRadScaler = Math.PI / 180.0d;
            double lengthScaler = 360.0d / length;

            short[] sineWave = new short[length];

            for (int i = 0; i < length; i++)
            {
                var phase = i * degToRadScaler * frequency * lengthScaler;

                var sin = short.MaxValue * Math.Sin(phase);

                sineWave[i] = Convert.ToInt16(sin);
            }

            return sineWave;
        }

        public static void AddLineSeries<T>(PlotModel plotModel, T[] inputData, OxyColor color)
        {
            Check.IsNull(plotModel);
            Check.IsNull(inputData);

            var lineSeries = new LineSeries()
            {
                Color = color
            };

            AddDataPointSeries(plotModel, inputData, lineSeries);
        }

        public static void AddBarSeries<T>(PlotModel plotModel, T[] inputData, OxyColor color)
        {
            Check.IsNull(plotModel);
            Check.IsNull(inputData);

            var barSeries = new LinearBarSeries()
            {
                FillColor = color,
                BarWidth = 45
            };

            AddDataPointSeries(plotModel, inputData, barSeries);
        }

        private static void AddDataPointSeries<T>(PlotModel plotModel, T[] inputData,
            DataPointSeries dataPointSeries)
        {
            for (int i = 0; i < inputData.Length; i++)
            {
                dataPointSeries.Points.Add(new DataPoint(i, Convert.ToDouble(inputData[i])));
            }

            plotModel.Series.Clear();
            plotModel.Series.Add(dataPointSeries);

            plotModel.InvalidatePlot(true);
        }
    }
}
