﻿using Motors.PwmProvider.ControllerProviders;
using Motors.PwmProvider.MotorsControl;
using MotorsControl.Enums;
using System;
using System.Threading.Tasks;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

namespace Motors.PwmProvider
{
    public sealed partial class MainPage : Page
    {
        // Motor direction
        private object directions;
        private MotorDirection motorDirection;

        // DC motor
        private object dcMotors;
        private DcMotorIndex dcMotorIndex;

        private ushort speed;
        private DcMotor dcMotor;

        public MainPage()
        {
            InitializeComponent();

            ConfigureDataSources();
        }

        public double Speed
        {
            get { return speed; }
            set
            {
                speed = Convert.ToUInt16(value);

                if (dcMotor != null)
                {
                    dcMotor.SetSpeed(dcMotorIndex, speed);
                }
            }
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            base.OnNavigatedTo(e);

            InitializeDcMotor();
        }

        private void ConfigureDataSources()
        {
            directions = Enum.GetValues(typeof(MotorDirection));
            dcMotors = Enum.GetValues(typeof(DcMotorIndex));         
        }

        private void ButtonStart_Click(object sender, RoutedEventArgs e)
        {
            if (dcMotor != null)
            {
                dcMotor.Start(dcMotorIndex, motorDirection);
            }
        }

        private void ButtonStop_Click(object sender, RoutedEventArgs e)
        {
            if (dcMotor != null)
            {
                dcMotor.Stop(dcMotorIndex);
            }
        }

        private void InitializeDcMotor()
        {
            var pcaPwmControllerProvider = PcaPwmControllerProvider.GetDefault();

            dcMotor = new DcMotor(pcaPwmControllerProvider);

            // Set default speed
            Speed = 1000;

            // DC motor test. Uncomment the following line to run DC1 motor for 5 seconds without using UI.            
            // DcMotorTest(DcMotorIndex.DC1, MotorDirection.Backward, speed);
        }

        private void DcMotorTest(DcMotorIndex motorIndex, MotorDirection direction, ushort speed)
        {
            if (dcMotor != null)
            {
                const int msDelay = 5000;

                // Set speed, and run motor
                dcMotor.SetSpeed(motorIndex, speed);
                dcMotor.Start(motorIndex, direction);

                // Wait a specified delay
                Task.Delay(msDelay).Wait();

                // Stop motor
                dcMotor.Stop(motorIndex);
            }
        }

    }
}
