﻿using MotorsControl.Enums;
using System;

namespace MotorsControl.PWM
{
    public static class PcaRegisters
    {
        public static byte Mode1 { get; } = 0x00;
        public static byte Prescale { get; } = 0xFE;

        public static byte SleepModeBitIndex { get; } = 4;        

        private const byte ledAddressBeginIndex = 0x06;
        private const byte channelOffset = 4;
        private const byte registerLength = 2;
        private const byte maxChannelIndex = 15;             

        public static byte[] GetRegisterAddressList(byte channelIndex, RegisterType registerType)
        {
            // Verify channel index
            if(channelIndex > maxChannelIndex)
            {
                throw new ArgumentException("Channel index cannot be larger than " 
                    + maxChannelIndex);
            }
            
            // Get start address by jumping 4 * channelIndex from the LED begin index of 6
            var registerStartAddress = Convert.ToByte(ledAddressBeginIndex 
                + channelIndex * channelOffset);

            // If register type is off, then add an additional offset of 2
            if(registerType == RegisterType.Off)
            {
                registerStartAddress += Convert.ToByte((byte)registerType * registerLength);
            }

            // Construct the address list
            var addressList = new byte[registerLength];

            for(byte i = 0; i < registerLength; i++)
            {
                addressList[i] = Convert.ToByte(registerStartAddress + i);
            }

            return addressList;
        }
    }
}
