﻿using System.ComponentModel;
using System.Runtime.CompilerServices;
using Windows.UI.Xaml.Media;

namespace AnomalyDetection.ViewModels
{
    public class AnomalyViewModel : INotifyPropertyChanged
    {
        #region Public properties

        public bool IsAcquisitionInProgress
        {
            get { return isAcquisitionInProgress; }
            set
            {
                isAcquisitionInProgress = value;
                OnPropertyChanged();

                IsAcquisitionButtonEnabled = !value;
                OnPropertyChanged("IsAcquisitionButtonEnabled");

                IsStartMonitoringButtonEnabled = !value;
                OnPropertyChanged("IsStartMonitoringButtonEnabled");

                IsStopMonitoringButtonEnabled = !value;
                OnPropertyChanged("IsStopMonitoringButtonEnabled");
            }
        }

        public bool IsTemperatureMonitoringEnabled
        {
            get { return isTemperatureMonitoringEnabled; }
            set
            {
                isTemperatureMonitoringEnabled = value;
                OnPropertyChanged();

                IsStartMonitoringButtonEnabled = !value;
                OnPropertyChanged("IsStartMonitoringButtonEnabled");

                IsStopMonitoringButtonEnabled = value;
                OnPropertyChanged("IsStopMonitoringButtonEnabled");

                IsAcquisitionButtonEnabled = !value;
                OnPropertyChanged("IsAcquisitionButtonEnabled");
            }
        }

        public SolidColorBrush TemperatureStatusColorBrush
        {
            get { return temperatureStatusColorBrush; }
            set
            {
                temperatureStatusColorBrush = value;
                OnPropertyChanged();
            }
        }

        public string FilePath
        {
            get { return filePath; }
            set
            {
                filePath = value;
                OnPropertyChanged();
            }
        }

        public float Temperature
        {
            get { return temperature; }
            set
            {
                temperature = value;
                OnPropertyChanged();
            }
        }

        public bool IsAcquisitionButtonEnabled { get; set; }
        public bool IsStartMonitoringButtonEnabled { get; set; }        
        public bool IsStopMonitoringButtonEnabled { get; set; }

        #endregion

        #region Events

        public event PropertyChangedEventHandler PropertyChanged = delegate { };

        #endregion

        #region Private fields

        private SolidColorBrush temperatureStatusColorBrush;

        private bool isAcquisitionInProgress;        
        private bool isTemperatureMonitoringEnabled;

        private string filePath;

        private float temperature;

        #endregion

        #region Private methods

        private void OnPropertyChanged([CallerMemberName] string propertyName = "")
        {
            PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        
        #endregion
    }
}
